function dx = Brusselator(t, x, u, p)
% BRUSSELATOR The Brusselator model of an autocatalytic reaction
%
%   [dXdT] = BRUSSELATOR(T,X,U,P) returns the time-derivatives of each
%       state variable given time (t), current state x(t), input u(t), 
%       and parameter values [p].
% 
%       The system has Nx = 2 state variables and Nu = 0 input variables
%           x = [X,Y],   u = []
%       The equations depend on a set of Np = 2 parameters
%           p = [A, B]    
%

    % -- Constant Parameters --
    A = p(1);
    B = p(2);

    % ---- Dynamic equations ----
    dx = [
            A + x(1)^2*x(2) - B*x(1) - x(1) ;	% dX_1 / dt
            B*x(1) - x(1)^2*x(2)            ;	% dX_2 / dt
        ];

% --
end
