function dx = Lorentz(t, x, u, p)
% LORENTZ The Lorentz Attractor dynamical system
%
%   [dXdT] = LORENTZ(T,X,U,P) returns the time-derivatives of each
%       state variable given time (t), current state x(t), input u(t), 
%       and parameter values [p].
% 
%       The system has Nx = 3 state variables and Nu = 0 input variables
%           x = [Px,Py,Pz],   u = []
%       The equations depend on a set of Np = 3 parameters
%           p = [rho, beta, sigma]    
%

	% -- Constant Parameters --
	rho   = p(1);
	beta  = p(2);
	sigma = p(3);

	% ---- Dynamic equations ----
	dx = [
			sigma * (x(2) - x(1))       ;	% dX_1 / dt
			x(1) * (rho - x(3))  - x(2) ;	% dX_2 / dt
			x(1) * x(2) - beta * x(3)   ;	% dX_3 / dt 
		];

% --
end
