function plotSimulation(t,X,ftitle)
% PLOTSIMULATION Plots the result of the Lorentz simulation
%
%   plotSimulation(T,X) generates an animation plotting the state x(t)
%       for time t \in [0,dT*K].
%

    figure()
    Nx = size(X,1);
    lw = 1.0; fs = 24;
    color_list = ["#0072BD", "#D95319", "#EDB120"];
    
    % General customization for the subplotes (1:3) and (4)
    %  + definition of the animatedLine objects
    subplot(1,4,1:3), aniLine_1 = [animatedline, animatedline, animatedline];
      title(ftitle)
      for nx = 1:Nx
        aniLine_1(nx).LineWidth = lw; aniLine_1(nx).Color = color_list(nx);
      end
      ylabel('$x(t)$','Interpreter','Latex')
      xlabel('$t$','Interpreter','Latex')
      legend("$x_" + string(1:Nx) + "$",'Location','southwest','Interpreter','Latex');
      axis([t([1 end]) min(X,[],'all') max(X,[],'all')])
      set(gca,'TickLabelInterpreter','Latex','FontSize',fs)

    subplot(1,4,4), aniLine_2 = animatedline;
      aniLine_2.LineWidth = lw;
      ylabel('$x_2(t)$','Interpreter','Latex')
      xlabel('$x_1(t)$','Interpreter','Latex')
      set(gca,'TickLabelInterpreter','Latex','FontSize',fs)  
      if Nx == 3
        zlabel('$x_3(t)$','Interpreter','Latex')
        axis([min(X(1,:)) max(X(1,:)) min(X(2,:)) max(X(2,:)) min(X(3,:)) max(X(3,:))])
        view(3)
      else
        axis([min(X(1,:)) max(X(1,:)) min(X(2,:)) max(X(2,:))])
      end

    % Loop through each datapoint to generate the animation
    for k = 1:5:numel(t)
        subplot(1,4,1:3)
          for nx = 1:Nx
            addpoints(aniLine_1(nx), t(k), X(nx,k))   % Adds a datapoint for x_1
          end
        subplot(1,4,4)
          if Nx == 3; addpoints(aniLine_2, X(1,k), X(2,k), X(3,k))  % Adds a datapoint in the 3D plot
          else;       addpoints(aniLine_2, X(1,k), X(2,k))          % Adds a datapoint in the 2D plot
          end
        
        drawnow limitrate     % Render the animation (limiting the framerate)
    end

% --
end